$set 3 #Configmenu

$ #ConfigOptions
# Opciones de Configuracin
$ #FocusModel
# Modelo del Foco
$ #WindowPlacement
# Ubicacin de las Ventanas
$ #ImageDithering
# Simulacin Ordenada de Colores en Imgenes
$ #OpaqueMove
# Movimiento Opaco de Ventanas
$ #FullMax
# Maximizacin Total
$ #FocusNew
# Enfocar Nuevas Ventanas
$ #FocusLast
# Enfocar la Ultima Ventana en el Escritorio
$ #DisableBindings
# Deshabilitar Enlaces con Bloq Despl
$ #ClickToFocus
# Click Para Enfocar
$ #SloppyFocus
# Foco Sigue Al Mouse
$ #AutoRaise
# Elevar Automticamente
$ #ClickRaise
# Click Para Elevar
$ #SmartRows
# Ubicacin Inteligente (Filas)
$ #SmartCols
# Ubicacin Inteligente (Columnas)
$ #Cascade
# Ubicacin en Cascada
$ #LeftRight
# Izquierda A Derecha
$ #RightLeft
# Derecha A Izquierda
$ #TopBottom
# De Arriba Abajo
$ #BottomTop
# De Abajo Arriba
$ #NoDithering
# Do not dither images
$ #OrderedDithering
# Use fast dither
$ #FloydSteinbergDithering
# Use high-quality dither
